﻿#target photoshop

// Your working documents must be 200% size

function main() {
    if(!documents.length) return;
    
    var sizes = {"retina":"100%", "normal":"50%"};
    var FILE_TYPE = ".png"; // The type of files that this script works on -- you can change
    var SEARCH_MASK = "*" + FILE_TYPE; // Image file filter to find only those files
    var folder, size;
    
    // get active document
    var docRef = app.activeDocument;
    $.writeln(docRef.showSliceNumbers);
    var outputFolder = Folder.selectDialog("Please select Output folder");
    if(outputFolder == null ) return;

    // Get current history state
    var history = docRef.activeHistoryState;

    for(var key  in sizes) {
        size = sizes[key];

        // Resize document
        docRef.resizeImage(size, size);
        
        // save for web
        var saveFile = File(outputFolder + "/" + "image.png");
        sfwPNG24(saveFile);
        
        // rename folder
        folder = Folder(outputFolder + "/images" );
        if (!folder.exists) {
            folder.create();
        }
        if(saveFile.exists) {
            moveFile(outputFolder + "/" + "image.png", outputFolder + "/images/image.png");
        }

        // restore previous state
        docRef.activeHistoryState =  history;

        if (key != "retina") continue; // skip if size isn't Retina
        
        // rename a 2x images 
        var fileList = folder.getFiles(SEARCH_MASK);
        for (var i = 0; i < fileList.length; i++) {
            var file = fileList[i];
            if ((file instanceof File) && (file.hidden == false) && file.name.indexOf ("@2x.png") == -1) {
                file.rename(file.name.replace(".png", "@2x.png"));
            }
        }
    }
}

function moveFile(oldPath, newPath) {
    var oldFile = new File(oldPath);
    var newFile = new File(newPath);
    
    if(!oldFile.exists) return;

    if(oldFile.copy(newFile)){
        oldFile.remove();
    }else{
        $.writeln('Cant move file');
    }
}

function sfwPNG24(saveFile){
    var pngOpts = new ExportOptionsSaveForWeb; 
    pngOpts.format = SaveDocumentType.PNG;
    pngOpts.PNG8 = false; 
    pngOpts.transparency = true; 
    pngOpts.interlaced = false; 
    pngOpts.quality = 100;
    pngOpts.includeProfile=true;
    activeDocument.exportDocument(new File(saveFile),ExportType.SAVEFORWEB,pngOpts); 
}

main();